Changelog
=========

This document describes changes between each past release.


0.2.0 (2018-09-25)
------------------

- Update to match kinto 10.1.1 -- see Kinto/kinto#1770 (#2).
- Add a heartbeat feature.


0.1.0 (2018-09-12)
------------------

- Initial implementation
